@@ -1,10 +1,11 @@
 package PICA::Data::Field;
 use v5.14.1;
 
-our $VERSION = '2.08';
+our $VERSION = '2.09';
 
 use Carp qw(croak);
 use Hash::MultiValue;
+use List::Util qw(first);
 
 sub new {
     my $class = shift;
@@ -133,12 +134,30 @@ sub set {
     push @$field, $code, $value;
 }
 
+sub equal {
+    my ($a, $b) = @_;
+    return (@$a == @$b && !defined first {$a->[$_] ne $b->[$_]} 0 .. $#{$b});
+}
+
+sub clone {
+    bless $_[0]->TO_JSON, 'PICA::Data::Field';
+}
+
 sub TO_JSON {
     [@{$_[0]}];
 }
 
 1;
 
+=head1 NAME
+
+PICA::Data::Field - PICA+ Field
+
+=head1 DESCRIPTION
+
+A PICA::Data::Field is a blessed array reference with tag, occurrence,
+subfields, and optional annotation.
+
 =head1 METHODS
 
 =head2 new( $tag, [$occ,] @subfields [,$annotation] )
@@ -172,4 +191,12 @@ subfield values. Changing subfields this way won't work!
 
 Set or append a subfield.
 
+=head2 equal( $field )
+
+Check whether the field is equal to another field.
+
+=head2 clone
+
+Return a copy of this field.
+
 =cut
